start abstract method

Future<String> start({
  1. String? path,
})

Start recording. If path is null, the adapter generates a temp path and returns it. The returned path is where the final recording will be written.

Implementation

Future<String> start({String? path});