skipBelowBytes property
Files at or below this byte size are returned unchanged (no re-encode). Default: 1 MB.
Implementation
final int skipBelowBytes;
Files at or below this byte size are returned unchanged (no re-encode). Default: 1 MB.
final int skipBelowBytes;