extractData<T> method
T?
extractData<T>(
- NyResponse<
T> enhancedResponse
inherited
Convenience method to extract just the data from an enhanced response This helps with migration from the old handleResponse method
Implementation
T? extractData<T>(NyResponse<T> enhancedResponse) {
return enhancedResponse.data;
}