displayValidationHint property
When true (default), shows the bottom hint listing max images and file constraints.
Implementation
final bool displayValidationHint;
When true (default), shows the bottom hint listing max images and file constraints.
final bool displayValidationHint;