dragPlaceholderBuilder property
Replaces the default drop-target placeholder (a white square) shown at the destination cell while a tile is being dragged over it.
Implementation
final Widget Function(BuildContext)? dragPlaceholderBuilder;
Replaces the default drop-target placeholder (a white square) shown at the destination cell while a tile is being dragged over it.
final Widget Function(BuildContext)? dragPlaceholderBuilder;