SingleAudioPicker class

SingleAudioPicker widget can be used to upload a single audio file. Two styles are available — see AudioPickerStyle.

Audio is picked via file_picker (no camera/gallery distinction). Pass AudioPickerOptions.allowedExtensions to constrain the picker dialog.

Inheritance

Constructors

SingleAudioPicker({Key? key, required Widget child(BuildContext context, Function upload), dynamic defaultAudio, AudioPickerOptions options = const AudioPickerOptions(), ApiRequest? apiUpload, required dynamic setAudioUrlFromResponse(dynamic response), Widget? loading, Function? onError, bool canUpdate = true, double? maxSize, List<String>? allowedMimeTypes})
SingleAudioPicker.simple({Key? key, dynamic defaultAudio, AudioPickerOptions options = const AudioPickerOptions(), ApiRequest? apiUpload, required dynamic setAudioUrlFromResponse(dynamic response), Widget? loading, Function? onError, bool canUpdate = true, double? maxSize, List<String>? allowedMimeTypes})
const

Properties

allowedMimeTypes List<String>?
final
apiUpload ApiRequest?
final
canUpdate bool
final
defaultAudio → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loading Widget?
final
maxSize double?
final
onError Function?
final
options AudioPickerOptions
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setAudioUrlFromResponse → dynamic Function(dynamic response)
final
style AudioPickerStyle
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited