SingleFilePicker class

SingleFilePicker widget can be used to upload a single arbitrary file. Two styles are available — see FilePickerStyle.

Use fileType to constrain the picker dialog. When fileType is MediaProFileType.custom, you must also pass allowedExtensions.

Inheritance

Constructors

SingleFilePicker({Key? key, required Widget builder(BuildContext context, Function upload, PickedFileInfo? picked), dynamic defaultFile, MediaProFileType fileType = MediaProFileType.any, List<String>? allowedExtensions, ApiRequest? apiUpload, required dynamic setFileUrlFromResponse(dynamic response), Widget? loading, Function? onError, bool canUpdate = true, double? maxSize, List<String>? allowedMimeTypes})
SingleFilePicker.simple({Key? key, dynamic defaultFile, MediaProFileType fileType = MediaProFileType.any, List<String>? allowedExtensions, ApiRequest? apiUpload, required dynamic setFileUrlFromResponse(dynamic response), Widget? loading, Function? onError, bool canUpdate = true, double? maxSize, List<String>? allowedMimeTypes})
const

Properties

allowedExtensions → List<String>?
final
allowedMimeTypes → List<String>?
final
apiUpload → ApiRequest?
final
canUpdate → bool
final
defaultFile → dynamic
final
fileType → MediaProFileType
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loading → Widget?
final
maxSize → double?
final
onError → Function?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setFileUrlFromResponse → dynamic Function(dynamic response)
final
style → FilePickerStyle
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited