CompressionTier class
One quality tier in an ImageCompressionOptions tier list.
Constructors
- CompressionTier({int? minBytes, required int jpegQuality})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- jpegQuality → int
-
JPEG quality (0-100) for files in this tier.
final
- minBytes → int?
-
Minimum byte size this tier applies to.
nullmeans catch-all (used when no other tier matches).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override