CustomImagePickerStyle class
Caller-supplied widget. The builder receives the upload callback so the rendered widget can trigger a pick + upload on tap.
- Inheritance
-
- Object
- ImagePickerStyle
- CustomImagePickerStyle
Constructors
- CustomImagePickerStyle(Widget builder(BuildContext context, Function upload))
-
const
Properties
- builder → Widget Function(BuildContext context, Function upload)
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited