UploadMode enum
Strategy for batch image uploads in GridImagePicker and MediaApiService.
Values
- standard → const UploadMode
-
Standard parallel multipart upload. Default. No compression, no gzip. Equivalent to MediaApiService.uploadImages.
- sequential → const UploadMode
-
Sequential multipart upload — one image per request. Use when the server can only accept one image at a time. Equivalent to MediaApiService.uploadImagesSequential.
- gzip → const UploadMode
-
Compressed batch upload with smart quality tiers + gzip. Sets
Content-Encoding: gzipheader. Server must support gzip multipart. Equivalent to MediaApiService.uploadImagesGzip.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
UploadMode> - A constant List of the values in this enum, in order of their declaration.