onUploadVideos property
Bypass MediaApiService entirely — receives the picked videos and is responsible for uploading + returning a list of items to merge into the grid.
Implementation
final Future<dynamic> Function(List<PickedFileInfo> videos)? onUploadVideos;