SingleVideoPicker class

SingleVideoPicker widget can be used to upload a single video from the gallery or camera. Three styles are available — see VideoPickerStyle.

Provide thumbnailGenerator to render a real poster from the picked video; without it the picker shows a generic video icon. Pass thumbnailUrl to display a remote poster for an already-uploaded video.

Inheritance

Constructors

SingleVideoPicker({Key? key, required Widget child(BuildContext context, Function upload), dynamic defaultVideo, String? thumbnailUrl, Future<File?> thumbnailGenerator(File video)?, VideoPickerOptions options = const VideoPickerOptions(), String videoSource = "gallery", String cameraDevice = "rear", ApiRequest? apiUpload, required dynamic setVideoUrlFromResponse(dynamic response), double height = 70, double width = 70, Widget? loading, Function? onError, bool canUpdate = true, BorderRadius? borderRadius, double? maxSize, List<String>? allowedMimeTypes})
SingleVideoPicker.compact({Key? key, dynamic defaultVideo, String? thumbnailUrl, Future<File?> thumbnailGenerator(File video)?, VideoPickerOptions options = const VideoPickerOptions(), String videoSource = "gallery", String cameraDevice = "rear", ApiRequest? apiUpload, required dynamic setVideoUrlFromResponse(dynamic response), double height = 100, double width = 100, Widget? loading, Function? onError, bool canUpdate = true, BorderRadius? borderRadius, double? maxSize, List<String>? allowedMimeTypes})
SingleVideoPicker.simple({Key? key, dynamic defaultVideo, String? thumbnailUrl, Future<File?> thumbnailGenerator(File video)?, VideoPickerOptions options = const VideoPickerOptions(), String videoSource = "gallery", String cameraDevice = "rear", ApiRequest? apiUpload, required dynamic setVideoUrlFromResponse(dynamic response), double height = 70, double width = 70, Widget? loading, Function? onError, bool canUpdate = true, BorderRadius? borderRadius, double? maxSize, List<String>? allowedMimeTypes})

Properties

allowedMimeTypes List<String>?
final
apiUpload ApiRequest?
final
borderRadius BorderRadius?
final
cameraDevice String
final
canUpdate bool
final
defaultVideo → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loading Widget?
final
maxSize double?
final
onError Function?
final
options VideoPickerOptions
final
picker → ImagePicker
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setVideoUrlFromResponse → dynamic Function(dynamic response)
final
style VideoPickerStyle
final
thumbnailGenerator Future<File?> Function(File video)?
final
thumbnailUrl String?
final
videoSource String
final
width double
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited